ViewportTextureRectangleRenderer

Struct ViewportTextureRectangleRenderer 

pub struct ViewportTextureRectangleRenderer<B = BindGroup> { /* private fields */ }
A renderer for applying a rectangle selection to ViewportTexture.

Implementations

Source

impl<B> ViewportTextureRectangleRenderer<B>

pub fn create_bind_group( &self, device: &Device, camera: &CameraBuffer, top_left: &ViewportTexturePosBuffer, bottom_right: &ViewportTexturePosBuffer, ) -> BindGroup

Create the bind group.

Source

impl ViewportTextureRectangleRenderer

pub const BIND_GROUP_LAYOUT_DESCRIPTOR: BindGroupLayoutDescriptor<'static>

The bind group layout descriptor.

pub fn new( device: &Device, texture: &ViewportTexture, camera: &CameraBuffer, top_left: &ViewportTexturePosBuffer, bottom_right: &ViewportTexturePosBuffer, ) -> Result<Self, RendererCreateError>

Create a new renderer.

pub fn render(&self, encoder: &mut CommandEncoder, texture: &ViewportTexture)

Render the rectangle.

pub fn render_with_pass(&self, pass: &mut RenderPass<'_>)

Render the rectangle with a wgpu::RenderPass.

Source

impl ViewportTextureRectangleRenderer<()>

pub fn new_without_bind_group( device: &Device, texture: &ViewportTexture, ) -> Result<Self, RendererCreateError>

Create a new renderer without internally managed bind group.

To create a bind group with layout matched to this renderer, use the ViewportTextureRectangleRenderer::create_bind_group method.

pub fn render( &self, encoder: &mut CommandEncoder, texture: &ViewportTexture, bind_group: &BindGroup, )

Render the rectangle.

pub fn render_with_pass( &self, pass: &mut RenderPass<'_>, bind_group: &BindGroup, )

Render the rectangle with a wgpu::RenderPass.