Preprocessor

Struct Preprocessor 

pub struct Preprocessor<G: GaussianPod, B = BindGroup> { /* private fields */ }
Preprocessor to preprocess the Gaussians.

It computes the depth for RadixSorter and do frustum culling.

Implementations

Source

impl<G: GaussianPod, B> Preprocessor<G, B>

pub fn create_bind_group( &self, device: &Device, camera: &CameraBuffer, model_transform: &ModelTransformBuffer, gaussian_transform: &GaussianTransformBuffer, gaussians: &GaussiansBuffer<G>, indirect_args: &IndirectArgsBuffer, radix_sort_indirect_args: &RadixSortIndirectArgsBuffer, indirect_indices: &IndirectIndicesBuffer, gaussians_depth: &GaussiansDepthBuffer, selection: &SelectionBuffer, invert_selection: &PreprocessorInvertSelectionBuffer, ) -> BindGroup

Create the bind group.

pub fn workgroup_size(&self) -> u32

Get the number of invocations in one workgroup.

pub fn bind_group_layout(&self) -> &BindGroupLayout

Get the bind group layouts.

Source

impl<G: GaussianPod> Preprocessor<G>

pub const BIND_GROUP_LAYOUT_DESCRIPTOR: BindGroupLayoutDescriptor<'static>

The bind group layout descriptor.

pub fn new( device: &Device, camera: &CameraBuffer, model_transform: &ModelTransformBuffer, gaussian_transform: &GaussianTransformBuffer, gaussians: &GaussiansBuffer<G>, indirect_args: &IndirectArgsBuffer, radix_sort_indirect_args: &RadixSortIndirectArgsBuffer, indirect_indices: &IndirectIndicesBuffer, gaussians_depth: &GaussiansDepthBuffer, selection: &SelectionBuffer, invert_selection: &PreprocessorInvertSelectionBuffer, ) -> Result<Self, PreprocessorCreateError>

Create a new preprocessor.

pub fn preprocess(&self, encoder: &mut CommandEncoder, gaussian_count: u32)

Preprocess the Gaussians.

Source

impl<G: GaussianPod> Preprocessor<G, ()>

pub fn new_without_bind_group( device: &Device, ) -> Result<Self, PreprocessorCreateError>

Create a new preprocessor without interally managed bind group.

To create a bind group with layout matched to this preprocessor, use the Preprocessor::create_bind_group method.

pub fn preprocess( &self, encoder: &mut CommandEncoder, bind_group: &BindGroup, gaussian_count: u32, )

Preprocess the Gaussians.