pub struct Preprocessor<G: GaussianPod, B = BindGroup> { /* private fields */ }Expand description
Preprocessor to preprocess the Gaussians.
It computes the depth for RadixSorter and do frustum culling.
Implementations
Sourceimpl<G: GaussianPod, B> Preprocessor<G, B>
impl<G: GaussianPod, B> Preprocessor<G, B>
Sourcepub fn create_bind_group(
&self,
device: &Device,
camera: &CameraBuffer,
model_transform: &ModelTransformBuffer,
gaussian_transform: &GaussianTransformBuffer,
gaussians: &GaussiansBuffer<G>,
indirect_args: &IndirectArgsBuffer,
radix_sort_indirect_args: &RadixSortIndirectArgsBuffer,
indirect_indices: &IndirectIndicesBuffer,
gaussians_depth: &GaussiansDepthBuffer,
selection: &SelectionBuffer,
invert_selection: &PreprocessorInvertSelectionBuffer,
) -> BindGroup
pub fn create_bind_group( &self, device: &Device, camera: &CameraBuffer, model_transform: &ModelTransformBuffer, gaussian_transform: &GaussianTransformBuffer, gaussians: &GaussiansBuffer<G>, indirect_args: &IndirectArgsBuffer, radix_sort_indirect_args: &RadixSortIndirectArgsBuffer, indirect_indices: &IndirectIndicesBuffer, gaussians_depth: &GaussiansDepthBuffer, selection: &SelectionBuffer, invert_selection: &PreprocessorInvertSelectionBuffer, ) -> BindGroup
Create the bind group.
Sourcepub fn workgroup_size(&self) -> u32
pub fn workgroup_size(&self) -> u32
Get the number of invocations in one workgroup.
Sourcepub fn bind_group_layout(&self) -> &BindGroupLayout
pub fn bind_group_layout(&self) -> &BindGroupLayout
Get the bind group layouts.
Sourceimpl<G: GaussianPod> Preprocessor<G>
impl<G: GaussianPod> Preprocessor<G>
Sourcepub const BIND_GROUP_LAYOUT_DESCRIPTOR: BindGroupLayoutDescriptor<'static>
pub const BIND_GROUP_LAYOUT_DESCRIPTOR: BindGroupLayoutDescriptor<'static>
The bind group layout descriptor.
Sourcepub fn new(
device: &Device,
camera: &CameraBuffer,
model_transform: &ModelTransformBuffer,
gaussian_transform: &GaussianTransformBuffer,
gaussians: &GaussiansBuffer<G>,
indirect_args: &IndirectArgsBuffer,
radix_sort_indirect_args: &RadixSortIndirectArgsBuffer,
indirect_indices: &IndirectIndicesBuffer,
gaussians_depth: &GaussiansDepthBuffer,
selection: &SelectionBuffer,
invert_selection: &PreprocessorInvertSelectionBuffer,
) -> Result<Self, PreprocessorCreateError>
pub fn new( device: &Device, camera: &CameraBuffer, model_transform: &ModelTransformBuffer, gaussian_transform: &GaussianTransformBuffer, gaussians: &GaussiansBuffer<G>, indirect_args: &IndirectArgsBuffer, radix_sort_indirect_args: &RadixSortIndirectArgsBuffer, indirect_indices: &IndirectIndicesBuffer, gaussians_depth: &GaussiansDepthBuffer, selection: &SelectionBuffer, invert_selection: &PreprocessorInvertSelectionBuffer, ) -> Result<Self, PreprocessorCreateError>
Create a new preprocessor.
Sourcepub fn preprocess(&self, encoder: &mut CommandEncoder, gaussian_count: u32)
pub fn preprocess(&self, encoder: &mut CommandEncoder, gaussian_count: u32)
Preprocess the Gaussians.
Sourceimpl<G: GaussianPod> Preprocessor<G, ()>
impl<G: GaussianPod> Preprocessor<G, ()>
Sourcepub fn new_without_bind_group(
device: &Device,
) -> Result<Self, PreprocessorCreateError>
pub fn new_without_bind_group( device: &Device, ) -> Result<Self, PreprocessorCreateError>
Create a new preprocessor without interally managed bind group.
To create a bind group with layout matched to this preprocessor, use the
Preprocessor::create_bind_group method.
Sourcepub fn preprocess(
&self,
encoder: &mut CommandEncoder,
bind_group: &BindGroup,
gaussian_count: u32,
)
pub fn preprocess( &self, encoder: &mut CommandEncoder, bind_group: &BindGroup, gaussian_count: u32, )
Preprocess the Gaussians.